@@ -8,12 +8,9 @@ ENABLED = os.environ.get('VALIDATE_SPATIAL', 'true') == 'true'
 gee_init = False
 
 
-def _init_gee():
-    global gee_init
-    if gee_init:
-        return
-    init_gee()
-    gee_init = True
+def init_gee_by_nodes(nodes: list):
+    should_init = any([n.get('@type', n.get('type')) in ['Site', 'Organisation'] for n in nodes])
+    return init_gee() if should_init and ENABLED else None
 
 
 def is_enabled(): return ENABLED
@@ -23,12 +20,10 @@ def id_to_level(id: str): return id.count('.')
 
 
 def fetch_data(**kwargs):
-    _init_gee()
     return run(kwargs).get('features', [])[0].get('properties')
 
 
 def get_region_id(gid: str, **kwargs):
-    _init_gee()
     try:
         level = id_to_level(gid)
         field = f"GID_{level}"
@@ -43,10 +38,8 @@ def get_region_id(gid: str, **kwargs):
 
 
 def get_region_size(gid: str):
-    _init_gee()
     return area_km2(load_region(gid).geometry()).getInfo()
 
 
 def get_boundary_size(boundary: dict):
-    _init_gee()
     return area_km2(load_geometry(boundary)).getInfo()
