@@ -3,8 +3,7 @@ import json
 from typing import List
 from functools import reduce
 from datetime import datetime
-from hestia_earth.schema import SchemaType, TermTermType
-from hestia_earth.utils.api import download_hestia, search
+from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.tools import list_average, safe_parse_date, list_sum
 
 
@@ -39,6 +38,9 @@ def _safe_cast(val, to_type, default=None):
 def _hash_dict(value: dict): return json.dumps(value, sort_keys=True)
 
 
+def _is_number(value): return value is not None and (isinstance(value, float) or isinstance(value, int))
+
+
 def _is_same_dict(a: dict, b: dict): return _hash_dict(a) == _hash_dict(b)
 
 
@@ -112,12 +114,14 @@ def _same_properties(value: dict, props: List[str]):
 def _value_average(node: dict, default=0, key='value'):
     try:
         value = node.get(key)
-        is_number = value is not None and (isinstance(value, float) or isinstance(value, int))
-        return value if is_number else list_average(value, default)
+        return list_average(value, default) if isinstance(value, list) else value
     except Exception:
         return default
 
 
+def term_id_prefix(term_id: str): return term_id.split('Kg')[0]
+
+
 def _download_linked_node(node: dict):
     data = download_hestia(node.get('@id'), node.get('@type')) if node.get('@id') and node.get('@type') else None
     return data if (data or {}).get('@id') == node.get('@id') else None
@@ -204,46 +208,3 @@ def run_model_from_node(node: dict, data: dict):
     methodModel = node.get('methodModel', {}).get('@id')
     term_id = node.get('term', {}).get('@id')
     return run_model(methodModel, term_id, data)
-
-
-def get_fuel_terms():
-    """
-    Find all "liquid" `fuel` terms from the Glossary:
-    - https://hestia.earth/glossary?termType=fuel&query=gasoline
-    - https://hestia.earth/glossary?termType=fuel&query=diesel
-
-    Returns
-    -------
-    list
-        List of matching term `@id` as `str`.
-    """
-    terms = search({
-        "bool": {
-            "must": [
-                {
-                    "match": {
-                        "@type": SchemaType.TERM.value
-                    }
-                },
-                {
-                    "match": {
-                        "termType.keyword": TermTermType.FUEL.value
-                    }
-                }
-            ],
-            "should": [
-                {
-                    "regexp": {
-                        "name": "*gasoline*"
-                    }
-                },
-                {
-                    "regexp": {
-                        "name": "*diesel*"
-                    }
-                }
-            ],
-            "minimum_should_match": 1
-        }
-    }, limit=100)
-    return list(map(lambda n: n['@id'], terms))
