@@ -1,11 +1,11 @@
-from hestia_earth.schema import SchemaType, CycleFunctionalUnit, SiteSiteType, TermTermType
+from hestia_earth.schema import CycleFunctionalUnit, SiteSiteType, TermTermType
 from hestia_earth.utils.tools import flatten, list_sum
 from hestia_earth.utils.date import diff_in_days, is_in_days
-from hestia_earth.utils.api import find_node
 from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
 
 from hestia_earth.validation.utils import _find_linked_node, _value_average, _list_sum_terms
+from hestia_earth.validation.terms import get_crop_residue_terms
 from .shared import (
     validate_dates, validate_list_dates, validate_date_lt_today, validate_list_min_below_max,
     validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length, validate_list_date_lt_today,
@@ -20,9 +20,9 @@ from .practice import (
 )
 from .product import (
     validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta,
-    validate_primary as validate_product_primary
+    validate_primary as validate_product_primary, validate_product_ha_functional_unit_ha
 )
-from .data_completeness import validate_dataCompleteness
+from .completeness import validate_completeness
 from .transformation import (
     validate_previous_transformation, validate_first_transformation_fields, validate_transformation_excretaManagement,
     validate_first_transformation_input, validate_linked_emission
@@ -98,13 +98,8 @@ def validate_sum_aboveGroundCropResidue(products: list):
     }
 
 
-def _crop_residue_terms():
-    terms = find_node(SchemaType.TERM, {'termType': TermTermType.CROPRESIDUE.value})
-    return [term.get('@id') for term in terms if term.get('@id')]
-
-
 def validate_crop_residue_completeness(cycle: dict, site: dict):
-    terms = _crop_residue_terms()
+    terms = get_crop_residue_terms()
 
     def validate_sum():
         products = cycle.get('products', [])
@@ -116,7 +111,7 @@ def validate_crop_residue_completeness(cycle: dict, site: dict):
             'message': 'the sum of above ground crop residue and below ground crop residue must be greater than zero'
         }
 
-    data_completeness = cycle.get('dataCompleteness', {}).get(TermTermType.CROPRESIDUE.value)
+    data_completeness = cycle.get('completeness', {}).get(TermTermType.CROPRESIDUE.value)
     site_type = site.get('siteType')
     return data_completeness is False or site_type not in SITE_TYPES_RESTRICTED or validate_sum()
 
@@ -194,82 +189,90 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_linked_source_privacy(cycle, 'defaultSource', node_map),
         validate_private_has_source(cycle, 'defaultSource'),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
-        validate_dataCompleteness(cycle, site) if 'dataCompleteness' in cycle else True,
+        validate_completeness(cycle, site) if 'completeness' in cycle else True,
         validate_siteDuration(cycle),
         validate_otherSites_cycleDuration(cycle),
         validate_possibleCoverCrop(cycle)
-    ]) + flatten([
-        validate_list_model(cycle, 'emissions'),
-        validate_list_dates(cycle, 'emissions'),
-        validate_list_dates_format(cycle, 'emissions'),
-        validate_list_min_below_max(cycle, 'emissions'),
-        validate_list_value_between_min_max(cycle, 'emissions'),
-        validate_list_term_percent(cycle, 'emissions'),
-        validate_list_dates_length(cycle, 'emissions'),
-        validate_list_date_lt_today(cycle, 'emissions', ['startDate', 'endDate']),
-        validate_properties_default_value(cycle, 'emissions'),
-        validate_properties_valueType(cycle, 'emissions'),
-        validate_linked_terms(cycle, 'emissions', 'inputs', 'inputs', True),
-        validate_linked_terms(cycle, 'emissions', 'transformation', 'transformations', True)
-    ] if len(cycle.get('emissions', [])) > 0 else []) + flatten([
-        validate_list_dates(cycle, 'inputs'),
-        validate_list_dates_format(cycle, 'inputs'),
-        validate_list_dates_length(cycle, 'inputs'),
-        validate_list_date_lt_today(cycle, 'inputs', ['startDate', 'endDate']),
-        validate_list_min_below_max(cycle, 'inputs'),
-        validate_list_value_between_min_max(cycle, 'inputs'),
-        validate_list_term_percent(cycle, 'inputs'),
-        validate_properties_default_value(cycle, 'inputs'),
-        validate_properties_valueType(cycle, 'inputs'),
-        validate_volatileSolidsContent(cycle, 'inputs'),
-        validate_must_include_id(cycle['inputs']),
-        validate_input_country(cycle, 'inputs'),
-        validate_related_impacts(cycle, 'inputs', node_map)
-    ] if len(cycle.get('inputs', [])) > 0 else []) + flatten([
-        validate_list_dates(cycle, 'products'),
-        validate_list_dates_format(cycle, 'products'),
-        validate_list_dates_length(cycle, 'products'),
-        validate_list_date_lt_today(cycle, 'products', ['startDate', 'endDate']),
-        validate_list_min_below_max(cycle, 'products'),
-        validate_list_value_between_min_max(cycle, 'products'),
-        validate_list_term_percent(cycle, 'products'),
-        validate_economicValueShare(cycle.get('products')),
-        validate_sum_aboveGroundCropResidue(cycle.get('products')),
-        validate_value_empty(cycle.get('products')),
-        validate_value_0(cycle.get('products')),
-        validate_product_primary(cycle.get('products')),
-        validate_properties_default_value(cycle, 'products'),
-        validate_properties_valueType(cycle, 'products'),
-        validate_volatileSolidsContent(cycle, 'products'),
-        validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True,
-        validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG),
-        validate_excreta(cycle, 'products')
-    ] if len(cycle.get('products', [])) > 0 else []) + flatten([
-        validate_list_dates(cycle, 'practices'),
-        validate_list_dates_format(cycle, 'practices'),
-        validate_list_date_lt_today(cycle, 'practices', ['startDate', 'endDate']),
-        validate_list_min_below_max(cycle, 'practices'),
-        validate_list_value_between_min_max(cycle, 'practices'),
-        validate_list_term_percent(cycle, 'practices'),
-        validate_cropResidueManagement(cycle.get('practices')),
-        validate_longFallowPeriod(cycle.get('practices')),
-        validate_properties_default_value(cycle, 'practices'),
-        validate_properties_valueType(cycle, 'practices'),
-        validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value),
-        validate_excretaManagement(cycle, cycle.get('practices')),
-        validate_no_tillage(cycle.get('practices')),
-        validate_tillage_site_type(cycle.get('practices'), site) if site else True,
-        validate_tillage_values(cycle.get('practices')),
-        validate_liveAnimal_system(cycle)
-    ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
-        validate_functionalUnit(cycle, site)
-    ] if 'functionalUnit' in cycle and site else []) + flatten([
-        validate_list_dates(cycle, 'transformations'),
-        validate_list_dates_format(cycle, 'transformations'),
-        validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
-        validate_previous_transformation(cycle.get('transformations')),
-        validate_first_transformation_fields(cycle.get('transformations')),
-        validate_first_transformation_input(cycle, cycle.get('transformations')),
-        validate_transformation_excretaManagement(cycle.get('transformations')),
-        validate_linked_emission(cycle, 'transformations')
-    ] if len(cycle.get('transformations', [])) > 0 else [])
+    ]) + flatten(
+        ([
+            validate_functionalUnit(cycle, site)
+        ] if 'functionalUnit' in cycle and site else []) +
+        ([
+            validate_list_model(cycle, 'emissions'),
+            validate_list_dates(cycle, 'emissions'),
+            validate_list_dates_format(cycle, 'emissions'),
+            validate_list_min_below_max(cycle, 'emissions'),
+            validate_list_value_between_min_max(cycle, 'emissions'),
+            validate_list_term_percent(cycle, 'emissions'),
+            validate_list_dates_length(cycle, 'emissions'),
+            validate_list_date_lt_today(cycle, 'emissions', ['startDate', 'endDate']),
+            validate_properties_default_value(cycle, 'emissions'),
+            validate_properties_valueType(cycle, 'emissions'),
+            validate_linked_terms(cycle, 'emissions', 'inputs', 'inputs', True),
+            validate_linked_terms(cycle, 'emissions', 'transformation', 'transformations', True)
+        ] if len(cycle.get('emissions', [])) > 0 else []) +
+        ([
+            validate_list_dates(cycle, 'inputs'),
+            validate_list_dates_format(cycle, 'inputs'),
+            validate_list_dates_length(cycle, 'inputs'),
+            validate_list_date_lt_today(cycle, 'inputs', ['startDate', 'endDate']),
+            validate_list_min_below_max(cycle, 'inputs'),
+            validate_list_value_between_min_max(cycle, 'inputs'),
+            validate_list_term_percent(cycle, 'inputs'),
+            validate_properties_default_value(cycle, 'inputs'),
+            validate_properties_valueType(cycle, 'inputs'),
+            validate_volatileSolidsContent(cycle, 'inputs'),
+            validate_must_include_id(cycle['inputs']),
+            validate_input_country(cycle, 'inputs'),
+            validate_related_impacts(cycle, 'inputs', node_map)
+        ] if len(cycle.get('inputs', [])) > 0 else []) +
+        ([
+            validate_list_dates(cycle, 'products'),
+            validate_list_dates_format(cycle, 'products'),
+            validate_list_dates_length(cycle, 'products'),
+            validate_list_date_lt_today(cycle, 'products', ['startDate', 'endDate']),
+            validate_list_min_below_max(cycle, 'products'),
+            validate_list_value_between_min_max(cycle, 'products'),
+            validate_list_term_percent(cycle, 'products'),
+            validate_economicValueShare(cycle.get('products')),
+            validate_sum_aboveGroundCropResidue(cycle.get('products')),
+            validate_value_empty(cycle.get('products')),
+            validate_value_0(cycle.get('products')),
+            validate_product_primary(cycle.get('products')),
+            validate_properties_default_value(cycle, 'products'),
+            validate_properties_valueType(cycle, 'products'),
+            validate_volatileSolidsContent(cycle, 'products'),
+            validate_crop_residue_completeness(cycle, site) if 'completeness' in cycle and site else True,
+            validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG),
+            validate_excreta(cycle, 'products'),
+            validate_product_ha_functional_unit_ha(cycle, 'products')
+        ] if len(cycle.get('products', [])) > 0 else []) +
+        ([
+            validate_list_dates(cycle, 'practices'),
+            validate_list_dates_format(cycle, 'practices'),
+            validate_list_date_lt_today(cycle, 'practices', ['startDate', 'endDate']),
+            validate_list_min_below_max(cycle, 'practices'),
+            validate_list_value_between_min_max(cycle, 'practices'),
+            validate_list_term_percent(cycle, 'practices'),
+            validate_cropResidueManagement(cycle.get('practices')),
+            validate_longFallowPeriod(cycle.get('practices')),
+            validate_properties_default_value(cycle, 'practices'),
+            validate_properties_valueType(cycle, 'practices'),
+            validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value),
+            validate_excretaManagement(cycle, cycle.get('practices')),
+            validate_no_tillage(cycle.get('practices')),
+            validate_tillage_site_type(cycle.get('practices'), site) if site else True,
+            validate_tillage_values(cycle.get('practices')),
+            validate_liveAnimal_system(cycle)
+        ] if len(cycle.get('practices', [])) > 0 else []) +
+        ([
+            validate_list_dates(cycle, 'transformations'),
+            validate_list_dates_format(cycle, 'transformations'),
+            validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
+            validate_previous_transformation(cycle.get('transformations')),
+            validate_first_transformation_fields(cycle.get('transformations')),
+            validate_first_transformation_input(cycle, cycle.get('transformations')),
+            validate_transformation_excretaManagement(cycle.get('transformations')),
+            validate_linked_emission(cycle, 'transformations')
+        ] if len(cycle.get('transformations', [])) > 0 else [])
+    )
