@@ -54,16 +54,24 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
         validate_is_region(impact_assessment) if 'region' in impact_assessment else True,
         validate_region_in_country(impact_assessment) if 'region' in impact_assessment else True,
         validate_linked_cycle_product(impact_assessment, cycle) if cycle else True,
-    ] + flatten([
-        validate_list_model(impact_assessment, 'impacts'),
-        validate_list_min_below_max(impact_assessment, 'impacts'),
-        validate_list_value_between_min_max(impact_assessment, 'impacts'),
-        validate_list_term_percent(impact_assessment, 'impacts'),
-        validate_characterisedIndicator_model(impact_assessment, 'impacts')
-    ] if 'impacts' in impact_assessment else []) + flatten([
-        validate_list_min_below_max(impact_assessment, 'emissionsResourceUse'),
-        validate_list_value_between_min_max(impact_assessment, 'emissionsResourceUse'),
-        validate_list_term_percent(impact_assessment, 'emissionsResourceUse'),
-        validate_characterisedIndicator_model(impact_assessment, 'emissionsResourceUse'),
-        validate_landTransformation(impact_assessment, 'emissionsResourceUse')
-    ] if 'emissionsResourceUse' in impact_assessment else [])
+    ] + flatten(
+        ([
+            validate_list_min_below_max(impact_assessment, 'emissionsResourceUse'),
+            validate_list_value_between_min_max(impact_assessment, 'emissionsResourceUse'),
+            validate_list_term_percent(impact_assessment, 'emissionsResourceUse'),
+            validate_characterisedIndicator_model(impact_assessment, 'emissionsResourceUse'),
+            validate_landTransformation(impact_assessment, 'emissionsResourceUse')
+        ] if len(impact_assessment.get('emissionsResourceUse', [])) > 0 else []) +
+        ([
+            validate_list_min_below_max(impact_assessment, 'impacts'),
+            validate_list_value_between_min_max(impact_assessment, 'impacts'),
+            validate_list_term_percent(impact_assessment, 'impacts'),
+            validate_list_model(impact_assessment, 'impacts'),
+            validate_characterisedIndicator_model(impact_assessment, 'impacts')
+        ] if len(impact_assessment.get('impacts', [])) > 0 else []) +
+        ([
+            validate_list_min_below_max(impact_assessment, 'endpoints'),
+            validate_list_value_between_min_max(impact_assessment, 'endpoints'),
+            validate_list_term_percent(impact_assessment, 'endpoints')
+        ] if len(impact_assessment.get('endpoints', [])) > 0 else [])
+    )
