@@ -8,7 +8,7 @@ from .shared import validate_country
 
 MUST_INCLUDE_ID_COL = column_name('mustIncludeId')
 MUST_INCLUDE_ID_TERM_TYPES = [
-    TermTermType.INORGANICFERTILIZER.value
+    TermTermType.INORGANICFERTILISER.value
 ]
 
 
@@ -27,7 +27,7 @@ def validate_must_include_id(inputs: list):
         should_validate = term.get('termType') in MUST_INCLUDE_ID_TERM_TYPES
         missing_ids = missingRequiredIds(term) if should_validate else []
         return len(missing_ids) == 0 or {
-            'level': 'error',
+            'level': 'warning',  # added gap-filling which makes it non-required anymore
             'dataPath': f".inputs[{index}]",
             'message': f"should add missing inputs: {', '.join(missing_ids)}"
         }
