@@ -1,4 +1,4 @@
-from hestia_earth.schema import TermTermType
+from hestia_earth.schema import TermTermType, CycleFunctionalUnit
 from hestia_earth.utils.model import find_primary_product
 from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
 from hestia_earth.utils.tools import list_sum, flatten, non_empty_list
@@ -124,3 +124,24 @@ def validate_excreta(cycle: dict, list_key: str = 'products'):
         ) or True
 
     return _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
+
+
+def validate_product_ha_functional_unit_ha(cycle: dict, list_key: str = 'products'):
+    functional_unit = cycle.get('functionalUnit', CycleFunctionalUnit.RELATIVE.value)
+
+    def validate(values: tuple):
+        index, product = values
+        term_units = product.get('term', {}).get('units')
+        value = list_sum(product.get('value', [0]))
+        print(term_units, value)
+        return term_units != 'ha' or value <= 1 or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}].value",
+            'message': 'must be below or equal to 1 for unit in ha',
+            'params': {
+                'term': product.get('term', {})
+            }
+        }
+
+    return functional_unit != CycleFunctionalUnit._1_HA.value or \
+        _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
