@@ -10,7 +10,7 @@ from hestia_earth.earth_engine.gee_utils import MAX_AREA_SIZE
 from hestia_earth.validation.geojson import get_geojson_area
 from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id, get_region_size, get_boundary_size
 from hestia_earth.validation.utils import (
-    update_error_path, _filter_list_errors, _next_error, _value_average,
+    update_error_path, _filter_list_errors, _next_error, _value_average, _is_number,
     _find_linked_node, _is_before_today, run_model_from_node, run_model, _value_from_model, _get_dict_key,
     _list_except_item, _dict_without_key, _hash_dict, _value_range_error
 )
@@ -182,13 +182,13 @@ def validate_list_duplicate_values(node: dict, list_key: str, prop: str, value:
 
 
 def validate_list_term_percent(node: dict, list_key: str):
-    def soft_validate(index: int, value): return 0 < value and value <= 1 and {
+    def soft_validate(index: int, value): return (_is_number(value) and 0 < value and value <= 1) and {
         'level': 'warning',
         'dataPath': f".{list_key}[{index}].value",
         'message': 'may be between 0 and 100'
     }
 
-    def hard_validate(index: int, value): return (0 <= value and value <= 100) or {
+    def hard_validate(index: int, value): return (_is_number(value) and 0 <= value and value <= 100) or {
         'level': 'error',
         'dataPath': f".{list_key}[{index}].value",
         'message': 'should be between 0 and 100 (percentage)'
@@ -197,8 +197,9 @@ def validate_list_term_percent(node: dict, list_key: str):
     def validate(values: tuple):
         index, blank_node = values
         units = blank_node.get('term', {}).get('units', '')
-        value = _value_average(blank_node, None) if units == '%' else None
-        return value is None or type(value) == str or soft_validate(index, value) or hard_validate(index, value)
+        value = _value_average(blank_node, blank_node.get('value')) if units == '%' else None
+        is_empty = value is None or (isinstance(value, list) and len(value) == 0)
+        return is_empty or soft_validate(index, value) or hard_validate(index, value)
 
     return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
 
@@ -508,15 +509,15 @@ def validate_list_model(node: dict, list_key: str) -> list:
     return _filter_list_errors(errors)
 
 
-def _reset_dataCompleteness(node: dict):
-    dataCompleteness = node.get('dataCompleteness', {})
-    dataCompleteness = reduce(lambda prev, curr: {**prev, curr: False}, dataCompleteness.keys(), dataCompleteness)
-    return {**node, 'dataCompleteness': dataCompleteness}
+def _reset_completeness(node: dict):
+    completeness = node.get('completeness', {})
+    completeness = reduce(lambda prev, curr: {**prev, curr: False}, completeness.keys(), completeness)
+    return {**node, 'completeness': completeness}
 
 
 def _validate_list_model_config(node: dict, list_key: str, conf: dict):
     def validate_model(term: dict, value: float, index: int, model_conf: dict):
-        node_run = _reset_dataCompleteness(node) if model_conf.get('resetDataCompleteness', False) else node
+        node_run = _reset_completeness(node) if model_conf.get('resetDataCompleteness', False) else node
         expected_result = run_model(model_conf['model'], term.get('@id'), node_run)
         expected_value = _value_from_model(expected_result)
         delta = value_difference(value, expected_value)
