@@ -110,40 +110,44 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_area_size(site),
         validate_boundary_size(site) if need_validate_boundary_size(site) else True,
         validate_region_size(site) if need_validate_region_size(site) else True
-    ] + flatten([
-        validate_list_dates(site, 'measurements'),
-        validate_list_dates_format(site, 'measurements'),
-        validate_list_date_lt_today(site, 'measurements', ['startDate', 'endDate']),
-        validate_list_min_below_max(site, 'measurements'),
-        validate_list_value_between_min_max(site, 'measurements'),
-        validate_list_min_max_lookup(site, 'measurements', 'value'),
-        validate_list_min_max_lookup(site, 'measurements', 'min'),
-        validate_list_min_max_lookup(site, 'measurements', 'max'),
-        validate_list_term_percent(site, 'measurements'),
-        validate_soilTexture(site.get('measurements')),
-        validate_depths(site.get('measurements')),
-        validate_required_depths(site, 'measurements'),
-        validate_term_unique(site.get('measurements')),
-        validate_properties_default_value(site, 'measurements'),
-        validate_properties_valueType(site, 'measurements'),
-        validate_require_startDate_endDate(site, 'measurements'),
-        validate_with_models(site, 'measurements'),
-        validate_value_length(site, 'measurements')
-    ] if 'measurements' in site else []) + flatten([
-        validate_list_dates(site, 'infrastructure'),
-        validate_list_dates_format(site, 'infrastructure'),
-        validate_list_date_lt_today(site, 'infrastructure', ['startDate', 'endDate']),
-        validate_lifespan(site.get('infrastructure'))
-    ] if 'infrastructure' in site else []) + flatten([
-        validate_list_dates(site, 'practices'),
-        validate_list_dates_format(site, 'practices'),
-        validate_list_date_lt_today(site, 'practices', ['startDate', 'endDate']),
-        validate_list_min_below_max(site, 'practices'),
-        validate_list_value_between_min_max(site, 'practices'),
-        validate_list_term_percent(site, 'practices'),
-        validate_cropResidueManagement(site.get('practices')),
-        validate_longFallowPeriod(site.get('practices')),
-        validate_no_tillage(site.get('practices')),
-        validate_properties_default_value(site, 'practices'),
-        validate_properties_valueType(site, 'practices')
-    ] if 'practices' in site else [])
+    ] + flatten(
+        ([
+            validate_list_dates(site, 'infrastructure'),
+            validate_list_dates_format(site, 'infrastructure'),
+            validate_list_date_lt_today(site, 'infrastructure', ['startDate', 'endDate']),
+            validate_lifespan(site.get('infrastructure'))
+        ] if 'infrastructure' in site else []) +
+        ([
+            validate_list_dates(site, 'measurements'),
+            validate_list_dates_format(site, 'measurements'),
+            validate_list_date_lt_today(site, 'measurements', ['startDate', 'endDate']),
+            validate_list_min_below_max(site, 'measurements'),
+            validate_list_value_between_min_max(site, 'measurements'),
+            validate_list_min_max_lookup(site, 'measurements', 'value'),
+            validate_list_min_max_lookup(site, 'measurements', 'min'),
+            validate_list_min_max_lookup(site, 'measurements', 'max'),
+            validate_list_term_percent(site, 'measurements'),
+            validate_soilTexture(site.get('measurements')),
+            validate_depths(site.get('measurements')),
+            validate_required_depths(site, 'measurements'),
+            validate_term_unique(site.get('measurements')),
+            validate_properties_default_value(site, 'measurements'),
+            validate_properties_valueType(site, 'measurements'),
+            validate_require_startDate_endDate(site, 'measurements'),
+            validate_with_models(site, 'measurements'),
+            validate_value_length(site, 'measurements')
+        ] if len(site.get('measurements', [])) > 0 else []) +
+        ([
+            validate_list_dates(site, 'practices'),
+            validate_list_dates_format(site, 'practices'),
+            validate_list_date_lt_today(site, 'practices', ['startDate', 'endDate']),
+            validate_list_min_below_max(site, 'practices'),
+            validate_list_value_between_min_max(site, 'practices'),
+            validate_list_term_percent(site, 'practices'),
+            validate_cropResidueManagement(site.get('practices')),
+            validate_longFallowPeriod(site.get('practices')),
+            validate_no_tillage(site.get('practices')),
+            validate_properties_default_value(site, 'practices'),
+            validate_properties_valueType(site, 'practices')
+        ] if len(site.get('practices', [])) > 0 else [])
+    )
