@@ -1,8 +1,10 @@
-from hestia_earth.validation.validators.shared import is_value_different
-from hestia_earth.utils.model import find_term_match
+from hestia_earth.schema import TermTermType
+from hestia_earth.utils.api import download_hestia
+from hestia_earth.utils.model import find_term_match, filter_list_term_type
 from hestia_earth.utils.tools import flatten, list_sum
 
-from hestia_earth.validation.utils import _filter_list_errors, update_error_path
+from hestia_earth.validation.utils import _filter_list_errors, update_error_path, term_id_prefix
+from hestia_earth.validation.validators.shared import is_value_different
 from .practice import validate_excretaManagement
 
 
@@ -23,7 +25,7 @@ def _validate_previous_term(transformations: list, index: int):
 
 def _validate_previous_product_value(transformations: list, index: int):
     transformation = transformations[index]
-    share = transformation.get('previousTransformationShare', 100)
+    share = transformation.get('transformedShare', 100)
     inputs = transformation.get('inputs', [])
     previous_transformation = transformations[index - 1]
     products = previous_transformation.get('products', [])
@@ -60,7 +62,7 @@ def validate_first_transformation_fields(transformations: list):
             'message': 'must not be set on the first transformation'
         }
 
-    return not tr or _filter_list_errors(map(validate, ['previousTransformationTerm', 'previousTransformationShare']))
+    return not tr or _filter_list_errors(map(validate, ['previousTransformationTerm', 'transformedShare']))
 
 
 def validate_first_transformation_input(cycle: dict, transformations: list):
@@ -110,9 +112,41 @@ def validate_linked_emission(cycle: dict, list_key: str):
         return validate
 
     def validate(values: tuple):
-        index, blank_node = values
-        return _filter_list_errors(flatten(map(
-            validate_emission(index, blank_node), enumerate(blank_node.get('emissions', []))
-        )))
+        index, transformation = values
+        return _filter_list_errors(
+            map(validate_emission(index, transformation), enumerate(transformation.get('emissions', [])))
+        )
 
     return len(emissions) == 0 or _filter_list_errors(flatten(map(validate, enumerate(cycle.get(list_key, [])))))
+
+
+def _is_generic_excreta(term_id: str): return len((download_hestia(term_id) or {}).get('subClassOf', [])) == 0
+
+
+def validate_excreta_inputs_products(transformations: list):
+    def validate_product(transformation_index: int, input_prefix_ids: list[str]):
+        def validate(values: tuple):
+            index, product = values
+            term = product.get('term', {})
+            term_id = term.get('@id', '')
+            is_excreta = term.get('termType', '') == TermTermType.EXCRETA.value
+            return not is_excreta or _is_generic_excreta(term_id) or term_id_prefix(term_id) in input_prefix_ids or {
+                'level': 'error',
+                'dataPath': f".transformations[{transformation_index}].products[{index}]",
+                'message': 'must be included as an Input',
+                'params': {
+                    'term': term,
+                    'expected': input_prefix_ids
+                }
+            }
+        return validate
+
+    def validate(values: tuple):
+        index, transformation = values
+        excreta_inputs = filter_list_term_type(transformation.get('inputs', []), TermTermType.EXCRETA)
+        input_prefix_ids = list(set([term_id_prefix(v.get('term', {}).get('@id')) for v in excreta_inputs]))
+        return len(input_prefix_ids) == 0 or _filter_list_errors(
+            map(validate_product(index, input_prefix_ids), enumerate(transformation.get('products', [])))
+        )
+
+    return _filter_list_errors(flatten(map(validate, enumerate(transformations))))
