@@ -1,3 +1,4 @@
+from unittest.mock import patch
 import json
 
 from tests.utils import fixtures_path
@@ -14,11 +15,18 @@ from hestia_earth.validation.validators.cycle import (
     validate_possibleCoverCrop
 )
 
+class_path = 'hestia_earth.validation.validators.cycle'
+cropResidue = [
+    'aboveGroundCropResidueRemoved', 'aboveGroundCropResidueIncorporated', 'aboveGroundCropResidueTotal',
+    'aboveGroundCropResidueLeftOnField', 'aboveGroundCropResidueBurnt',
+    'belowGroundCropResidue'
+]
+
 
 def test_validate_valid():
     with open(f"{fixtures_path}/cycle/valid.json") as f:
         node = json.load(f)
-    assert validate_cycle(node) == [True] * 61
+    assert validate_cycle(node) == [True] * 62
 
 
 def test_validate_cycle_dates_valid():
@@ -150,14 +158,16 @@ def test_validate_sum_aboveGroundCropResidue_invalid():
     }
 
 
-def test_validate_crop_residue_completeness_valid():
-    with open(f"{fixtures_path}/cycle/dataCompleteness-cropResidue/valid.json") as f:
+@patch(f"{class_path}.get_crop_residue_terms", return_value=cropResidue)
+def test_validate_crop_residue_completeness_valid(*args):
+    with open(f"{fixtures_path}/cycle/completeness-cropResidue/valid.json") as f:
         data = json.load(f)
     assert validate_crop_residue_completeness(data, data.get('site')) is True
 
 
-def test_validate_crop_residue_completeness_invalid():
-    with open(f"{fixtures_path}/cycle/dataCompleteness-cropResidue/invalid.json") as f:
+@patch(f"{class_path}.get_crop_residue_terms", return_value=cropResidue)
+def test_validate_crop_residue_completeness_invalid(*args):
+    with open(f"{fixtures_path}/cycle/completeness-cropResidue/invalid.json") as f:
         data = json.load(f)
     assert validate_crop_residue_completeness(data, data.get('site')) == {
         'level': 'error',
