@@ -203,7 +203,7 @@ def test_validate_require_startDate_endDate_invalid():
     }]
 
 
-@patch("hestia_earth.models.spatial.rainfallAnnual._run", return_value={'value': [1000]})
+@patch("hestia_earth.models.spatial.precipitationAnnual._run", return_value={'value': [1000]})
 def test_validate_with_models_valid(*args):
     # no measurements should be valid
     assert validate_with_models({}, 'measurements') is True
@@ -213,7 +213,7 @@ def test_validate_with_models_valid(*args):
     assert validate_with_models(data, 'measurements') is True
 
 
-@patch("hestia_earth.models.spatial.rainfallAnnual._run", return_value={'value': [1000]})
+@patch("hestia_earth.models.spatial.precipitationAnnual._run", return_value={'value': [1000]})
 def test_validate_with_models_warning(*args):
     with open(f"{fixtures_path}/measurement/models/warning.json") as f:
         data = json.load(f)
@@ -227,7 +227,7 @@ def test_validate_with_models_warning(*args):
             'delta': 50,
             'threshold': 0.25,
             'term': {
-                '@id': 'rainfallAnnual',
+                '@id': 'precipitationAnnual',
                 '@type': 'Term',
                 'name': 'Rainfall annual'
             },
@@ -248,7 +248,7 @@ def test_validate_with_models_warning(*args):
             'delta': 100,
             'threshold': 0.25,
             'term': {
-                '@id': 'rainfallAnnual',
+                '@id': 'precipitationAnnual',
                 '@type': 'Term',
                 'name': 'Rainfall annual'
             },
