@@ -7,13 +7,11 @@ from hestia_earth.validation.validators.organisation import validate_organisatio
 class_path = 'hestia_earth.validation.validators.organisation'
 
 
-@patch(f"{class_path}.validate_boundary_size", return_value=True)
-@patch(f"{class_path}.validate_region_size", return_value=True)
 @patch(f"{class_path}.validate_coordinates", return_value=True)
 def test_validate_valid(*args):
     with open(f"{fixtures_path}/organisation/valid.json") as f:
         node = json.load(f)
-    assert validate_organisation(node) == [True] * 11
+    assert validate_organisation(node) == [True] * 8
 
 
 def test_validate_organisation_dates_valid():
