@@ -2,7 +2,8 @@ import json
 
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.product import (
-    validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta, validate_primary
+    validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta, validate_primary,
+    validate_product_ha_functional_unit_ha
 )
 
 
@@ -68,8 +69,8 @@ def test_validate_value_0_error():
                 'value': 100,
                 'term': {
                     "@type": "Term",
-                    "name": "Generic Crop, grain",
-                    "@id": "genericCropGrain"
+                    "name": "Generic Crop, seed",
+                    "@id": "genericCropSeed"
                 }
             }
         },
@@ -81,8 +82,8 @@ def test_validate_value_0_error():
                 'value': 100,
                 'term': {
                     "@type": "Term",
-                    "name": "Generic Crop, grain",
-                    "@id": "genericCropGrain"
+                    "name": "Generic Crop, seed",
+                    "@id": "genericCropSeed"
                 }
             }
         }
@@ -169,3 +170,29 @@ def test_validate_primary_error():
         'dataPath': '.products',
         'message': 'only 1 primary product allowed'
     }
+
+
+def test_validate_product_ha_functional_unit_ha_valid():
+    # no products should be valid
+    assert validate_product_ha_functional_unit_ha({'products': []}, 'products') is True
+
+    with open(f"{fixtures_path}/product/fu_ha/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_ha_functional_unit_ha(cycle, 'products') is True
+
+
+def test_validate_product_ha_functional_unit_ha_error():
+    with open(f"{fixtures_path}/product/fu_ha/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_product_ha_functional_unit_ha(cycle, 'products') == {
+        'level': 'error',
+        'dataPath': '.products[0].value',
+        'message': 'must be below or equal to 1 for unit in ha',
+        'params': {
+            'term': {
+                '@type': 'Term',
+                '@id': 'adzukiBeanVines',
+                'units': 'ha'
+            }
+        }
+    }
