@@ -378,10 +378,15 @@ def test_validate_list_term_percent_invalid():
     with open(f"{fixtures_path}/shared/unit-percent/invalid.json") as f:
         node = json.load(f)
     assert validate_list_term_percent(node, 'measurements') == {
-        'level': 'error',
-        'dataPath': '.measurements[0].value',
-        'message': 'should be between 0 and 100 (percentage)'
-    }
+            'level': 'error',
+            'dataPath': '.measurements[0].value',
+            'message': 'should be between 0 and 100 (percentage)'
+        }
+    assert validate_list_term_percent(node, 'practices') == {
+            'level': 'error',
+            'dataPath': '.practices[0].value',
+            'message': 'should be between 0 and 100 (percentage)'
+        }
 
 
 def test_validate_list_term_percent_warning():
